<?php 
/*
Plugin Name: I18N Custom Fields
Description: Custom Fields (I18N enabled)
Version: 1.4
Author: Martin Vlcek
Author URI: http://mvlcek.bplaced.net

Public functions:
  return_custom_field($name)
      return the value of the custom field with the given name for the current page

Display functions:
  get_custom_field($name)
      outputs the value of the custom field with the given name for the current page

*/

# get correct id for plugin
$thisfile = basename(__FILE__, ".php");

define('I18N_CUSTOMFIELDS_FILE', 'customfields.xml');

# register plugin
register_plugin(
	$thisfile,
	'I18N Custom Fields',
	'1.4',
  'Martin Vlcek',
  'http://mvlcek.bplaced.net/',
  'Custom fields for pages (I18N enabled) - based on Mike Swan\'s plugin',
	'plugins',
	'i18n_customfields_configure'
);

require_once(GSPLUGINPATH.'i18n_common/common.php');
i18n_merge('i18n_customfields') || i18n_merge('i18n_customfields', 'en_US');

add_action('index-pretemplate', 'i18n_get_custom_fields'); // add hook to make custom field values available to theme
add_action('header', 'i18n_customfields_header');            // add hook to create styles for custom field editor.
add_action('edit-extras', 'i18n_customfields_edit');         // add hook to create new inputs on the edit screen.
add_action('changedata-save', 'i18n_customfields_save');     // add hook to save custom field values 
add_action('plugins-sidebar', 'createSideMenu', array($thisfile, i18n_r('i18n_customfields/CUSTOMFIELDS_VIEW'))); 

$i18n_customfield_defs = null;

function i18n_customfield_defs(){
	global $i18n_customfield_defs;
  if ($i18n_customfield_defs == null) {
    $file = GSDATAOTHERPATH . I18N_CUSTOMFIELDS_FILE;
	  if (file_exists($file)) {
      $data = getXML($file);
		  $items = $data->item;
		  if (count($items) > 0) {
			  foreach ($items as $item) {
          $cf = array();
          $cf['key'] = (string) $item->desc;
          $cf['label'] = (string) $item->label;
          $cf['type'] = (string) $item->type;
          $cf['value'] = (string) $item->value;
          if ($item->type == "dropdown") {
            $cf['options'] = array();
            foreach ($item->option as $option) {
              $cf['options'][] = (string) $option;
            }
          }
          $i18n_customfield_defs[] = $cf;
			  }
		  } 
	  }
  }
  return $i18n_customfield_defs;
}

function i18n_customfields_save(){
	global $xml; // SimpleXML to save to
	$defs = i18n_customfield_defs();
  if (count($defs) > 0) {
    foreach ($defs as $def) {
      $key = $def['key'];
		  if(isset($_POST['post-'.strtolower($key)])) { 
			  $xml->addChild(strtolower($key))->addCData(stripslashes($_POST['post-'.strtolower($key)]));	
		  }
    }	
	}	
  // new field for creation date
  if (@$_POST['creDate']) {
    $xml->addChild('creDate', $_POST['creDate']);
  } else {
    $xml->addChild('creDate', (string) $xml->pubDate);
  }
}

function i18n_get_custom_fields() {
  global $customfields, $data_index;
  if (function_exists('return_i18n_languages')) return; // handled by I18N plugin
  $stdfields = array('pubDate','title','url','meta','metad','menu','menuStatus','menuOrder',
                      'template','parent','content','private','creDate');
  $customfields = array();
  if ($data_index) foreach ($data_index->children() as $child) {
    if (!in_array($child->getName(), $stdfields)) {
      $customfields[$child->getName()] = (string) $child;
    }
  }
}

if (!function_exists('get_custom_field')) {
  function get_custom_field($name) {
    global $customfields;
    echo @$customfields[$name];
  }
}

if (!function_exists('return_custom_field')) {
  function return_custom_field($name) {
    global $customfields;
    return @$customfields[$name];
  }
}

function get_page_creation_date($i = "l, F jS, Y - g:i A", $echo=true) {
	global $date;
	global $TIMEZONE;
	if ($TIMEZONE != '') {
		if (function_exists('date_default_timezone_set')) {
			date_default_timezone_set($TIMEZONE);
		}
	}
  $creDate = return_custom_field('creDate');
	$myVar = $creDate ? date($i, strtotime($creDate)) : null;
	if ($echo) {
		echo $myVar ? $myVar : '';
	} else {
		return $myVar;
	}
}

function i18n_customfields_header() {
?>
  <style type="text/css">
    form #metadata_window table.formtable td .cke_editor td:first-child { padding: 0; }
    form #metadata_window table.formtable .cke_editor td.cke_top { border-bottom: 1px solid #AAAAAA; }
    form #metadata_window table.formtable .cke_editor td.cke_contents { border: 1px solid #AAAAAA; }
    #customfieldsForm .hidden { display:none; }
  </style>
<?php
}

function i18n_customfields_edit() {
  include(GSPLUGINPATH.'i18n_customfields/edit.php');
}

function i18n_customfields_configure(){
  include(GSPLUGINPATH.'i18n_customfields/configure.php');
}
